This is the python package of the Reference View Synthesizer (RVS)

Please if you use it for research, cite:

@ARTICLE{9590541,
  author={Bonatto, Daniele and Fachada, Sarah and Rogge, Ségolène and Munteanu, Adrian and Lafruit, Gauthier},
  journal={IEEE Access}, 
  title={Real-Time Depth Video-Based Rendering for 6-DoF HMD Navigation and Light Field Displays}, 
  year={2021},
  volume={9},
  number={},
  pages={146868-146887},
  keywords={Rendering (computer graphics);Real-time systems;Navigation;Light fields;Resists;Three-dimensional displays;Streaming media;Virtual reality;stereo image processing;stereo vision;free viewpoint navigation;reference view synthesizer;real-time view synthesis},
  doi={10.1109/ACCESS.2021.3123529}
}